@@ -1,14 +1,25 @@
 import React, { useState } from 'react';
 
-import { storiesOf } from '@storybook/react';
-import { withCenteredStory } from '../../utils/storybook/withCenteredStory';
 import { Switch } from './Switch';
 import { text } from '@storybook/addon-knobs';
+import mdx from './Switch.mdx';
+
+const getStory = (title: string, component: any) => ({
+  title,
+  parameters: {
+    component,
+    docs: {
+      page: mdx,
+    },
+  },
+});
+
+export default getStory('UI|Switch', Switch);
 
 const getKnobs = () => {
   return {
     label: text('Label Text', 'Label'),
-    tooltip: text('Tooltip', null),
+    tooltip: text('Tooltip', ''),
   };
 };
 
@@ -18,6 +29,4 @@ const SwitchWrapper = () => {
   return <Switch label={label} checked={checked} onChange={() => setChecked(!checked)} tooltip={tooltip} />;
 };
 
-const story = storiesOf('UI/Switch', module);
-story.addDecorator(withCenteredStory);
-story.add('switch', () => <SwitchWrapper />);
+export const basic = () => <SwitchWrapper />;
